==> cockpit-podman-26-1-x86_64.pkg.tar.zst: usr/share/cockpit/podman/po.sk.js <==
(function (root, data) {
    var loaded, module;

    /* Load into Cockpit locale */
    if (typeof cockpit === 'object') {
        cockpit.locale(data)
        loaded = true;
    }

    if (!loaded)
        root.po = data;

/* The syntax of this line is important  by po2json */
}(this, {
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;
return plural;
},
  "language": "sk",
  "x-generator": "Weblate 4.3.2"
 },
 "Add item": [
  null,
  "Pridať položku"
 ],
 "Add on build variable": [
  null,
  ""
 ],
 "All": [
  null,
  "Všetky"
 ],
 "All registries": [
  null,
  "Všetky registre"
 ],
 "An error occured": [
  null,
  "Vyskytla sa chyba"
 ],
 "Author": [
  null,
  "Autor"
 ],
 "Automatically start podman on boot": [
  null,
  "Spúšťať podman pri zavádzaní systému"
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU shares": [
  null,
  "CPU podiely"
 ],
 "Cancel": [
  null,
  "Zrušiť"
 ],
 "Checkpoint": [
  null,
  "Vytvoriť kontrolný bod"
 ],
 "Checkpoint container $0": [
  null,
  "Vytvoriť kontrolný bod pre kontajner $0"
 ],
 "Command": [
  null,
  "Príkaz"
 ],
 "Commit": [
  null,
  "Vytvoriť"
 ],
 "Commit image": [
  null,
  "Vytvoriť obraz"
 ],
 "Console": [
  null,
  "Konzola"
 ],
 "Container": [
  null,
  "Kontajner"
 ],
 "Container failed to be created": [
  null,
  "Kontajner sa nepodarilo vytvoriť"
 ],
 "Container failed to be started": [
  null,
  "Kontajner sa nepodarilo spustiť"
 ],
 "Container is currently running.": [
  null,
  "Kontajner momentálne beží."
 ],
 "Container is not running": [
  null,
  "Kontajner nebeží"
 ],
 "Container name": [
  null,
  "Názov kontajneru"
 ],
 "Container path": [
  null,
  "Cesta v kontajneri"
 ],
 "Container port": [
  null,
  "Port kontajneru"
 ],
 "Containers": [
  null,
  "Kontajnery"
 ],
 "Created": [
  null,
  "Vytvorený"
 ],
 "Delete": [
  null,
  "Odstrániť"
 ],
 "Delete $0": [
  null,
  "Odstrániť $0"
 ],
 "Delete image": [
  null,
  "Zmazať obraz"
 ],
 "Delete tagged images": [
  null,
  "Zmazať označené obrazy"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "Zmazaním kontajneru sa zmažú všetky dáta v ňom."
 ],
 "Deleting this pod will remove the following containers:": [
  null,
  "Zmazanie tohto podu zmaže nasledujúce kontajnery:"
 ],
 "Details": [
  null,
  "Podrobnosti"
 ],
 "Do not include root file-system changes when exporting": [
  null,
  "Do exportu nezahŕnať zmeny v koreňovom súborovovom systéme"
 ],
 "Download": [
  null,
  "Stiahnuť"
 ],
 "Entrypoint": [
  null,
  "Vstupný bod"
 ],
 "Environment": [
  null,
  "Prostredie"
 ],
 "Error": [
  null,
  "Chyba"
 ],
 "Error message": [
  null,
  "Chybová správa"
 ],
 "Exited": [
  null,
  "Skončený"
 ],
 "Failed to checkpoint container $0": [
  null,
  "Nepodarilo sa vytvoriť kontrolný bod pre kontajner $0"
 ],
 "Failed to commit container $0": [
  null,
  ""
 ],
 "Failed to download image $0:$1": [
  null,
  "Nepodarilo sa stiahnuť obraz $0:$1"
 ],
 "Failed to force remove container $0": [
  null,
  "Nepodarilo sa vynútiť zmazanie kontajneru $0"
 ],
 "Failed to force stop pod $0": [
  null,
  "Nepodarilo sa vynútiť zmazanie podu $0"
 ],
 "Failed to pause pod $0": [
  null,
  "Nepodarilo sa zastaviť pod $0"
 ],
 "Failed to remove container $0": [
  null,
  "Nepodarilo sa zmazať kontajner $0"
 ],
 "Failed to restart container $0": [
  null,
  "Nepodarilo sa reštartovať kontajner $0"
 ],
 "Failed to restart pod $0": [
  null,
  "Nepodarilo sa reštartovať pod $0"
 ],
 "Failed to restore container $0": [
  null,
  "Nepodarilo sa obnoviť kontajner $0"
 ],
 "Failed to resume pod $0": [
  null,
  "Nepodarilo sa znovuspustiť pod $0"
 ],
 "Failed to search for images: $0": [
  null,
  "Nepodarilo sa nájsť obrazy: $0"
 ],
 "Failed to search for new images": [
  null,
  "Nepodarilo sa nájsť nové obrazy"
 ],
 "Failed to start container $0": [
  null,
  "Nepodarilo sa spustiť kontajner $0"
 ],
 "Failed to start pod $0": [
  null,
  "Nepodarilo sa spustiť pod $0"
 ],
 "Failed to stop container $0": [
  null,
  "Nepodarilo sa zastaviť kontajner $0"
 ],
 "Failed to stop pod $0": [
  null,
  "Nepodarilo sa zastaviť pod $0"
 ],
 "Force delete": [
  null,
  "Vynútiť odstránenie"
 ],
 "Force restart": [
  null,
  "Vynútiť reštartovanie"
 ],
 "Force stop": [
  null,
  "Vynútiť zastavenie"
 ],
 "Format": [
  null,
  "Formát"
 ],
 "Gateway": [
  null,
  "Brána"
 ],
 "Get new image": [
  null,
  "Získať nové obrazy"
 ],
 "GiB": [
  null,
  "GiB"
 ],
 "Hide intermediate images": [
  null,
  "Skryť dočasné obrazy"
 ],
 "Host path": [
  null,
  "Cesta na hostiteľovi"
 ],
 "Host port": [
  null,
  "Port na hostiteľovi"
 ],
 "ID": [
  null,
  "ID"
 ],
 "IP address": [
  null,
  "IP adresa"
 ],
 "IP prefix length": [
  null,
  "Dĺžka predpony IP adresy"
 ],
 "Ignore IP address if set statically": [
  null,
  "Ignorovať staticky nastavené IP adresy"
 ],
 "Ignore MAC address if set statically": [
  null,
  "Ignorovať staticky nastavené MAC adresy"
 ],
 "Image": [
  null,
  "Obraz"
 ],
 "Image name": [
  null,
  "Názov obrazu"
 ],
 "Images": [
  null,
  "Obrazy"
 ],
 "Keep all temporary checkpoint files": [
  null,
  ""
 ],
 "Key": [
  null,
  "Kľúč"
 ],
 "KiB": [
  null,
  "KiB"
 ],
 "Leave running after writing checkpoint to disk": [
  null,
  ""
 ],
 "Loading logs...": [
  null,
  "Načítanie záznamov udalostí..."
 ],
 "Loading...": [
  null,
  "Načítanie..."
 ],
 "Logs": [
  null,
  "Záznamy udalostí"
 ],
 "MAC address": [
  null,
  "MAC adresa"
 ],
 "Memory": [
  null,
  "Pamäť"
 ],
 "Memory limit": [
  null,
  "Pamäťový limit"
 ],
 "Message": [
  null,
  "Správa"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Multiple tags exist for this image. Select the tagged images to delete.": [
  null,
  ""
 ],
 "Name": [
  null,
  "Názov"
 ],
 "No SELinux label": [
  null,
  ""
 ],
 "No containers": [
  null,
  "Žiadne kontajnery"
 ],
 "No containers are using this image": [
  null,
  "Tento obraz nepoužívajú žiadne kontajnery"
 ],
 "No containers in this pod": [
  null,
  "V tomto pode nie sú žiadne kontajnery"
 ],
 "No containers that match the current filter": [
  null,
  ""
 ],
 "No images": [
  null,
  "Žiadne obrazy"
 ],
 "No images that match the current filter": [
  null,
  ""
 ],
 "No results for $0. Please retry another term.": [
  null,
  "Žiadne výsledky pre $0. Skúste iný pojem."
 ],
 "No running containers": [
  null,
  "Žiadne spustené kontajnery"
 ],
 "On build": [
  null,
  ""
 ],
 "Only running": [
  null,
  ""
 ],
 "Owner": [
  null,
  "Vlastník"
 ],
 "Pause": [
  null,
  "Pozastaviť"
 ],
 "Pause the container": [
  null,
  "Pozastaviť kontajner"
 ],
 "Paused": [
  null,
  "Pozastavený"
 ],
 "Please confirm deletion of $0": [
  null,
  "Potvrďte zmazanie $0"
 ],
 "Please confirm deletion of pod $0": [
  null,
  "Potvrďte zmazanie podu $0"
 ],
 "Please confirm force deletion of pod $0": [
  null,
  "Potvrďte vynútené zmazanie podu $0"
 ],
 "Please confirm forced deletion of $0": [
  null,
  ""
 ],
 "Podman containers": [
  null,
  "Podman kontajnery"
 ],
 "Podman service is not active": [
  null,
  "Služba Podman nie je aktívna"
 ],
 "Ports": [
  null,
  "Porty"
 ],
 "Private": [
  null,
  ""
 ],
 "Pulling": [
  null,
  "Sťahuje sa"
 ],
 "ReadOnly": [
  null,
  ""
 ],
 "ReadWrite": [
  null,
  ""
 ],
 "Remove item": [
  null,
  ""
 ],
 "Remove on build variable": [
  null,
  ""
 ],
 "Restart": [
  null,
  "Reštartovať"
 ],
 "Restore": [
  null,
  "Obnoviť"
 ],
 "Restore container $0": [
  null,
  "Obnovenie kontajneru $0"
 ],
 "Restore with established TCP connections": [
  null,
  ""
 ],
 "Resume": [
  null,
  ""
 ],
 "Run": [
  null,
  "Spustiť"
 ],
 "Run image": [
  null,
  "Spustiť obraz"
 ],
 "Running": [
  null,
  ""
 ],
 "Search by name or description": [
  null,
  "Hľadať podľa mena alebo popisu"
 ],
 "Search for": [
  null,
  ""
 ],
 "Search for an image": [
  null,
  "Hľadanie obrazu"
 ],
 "Set container on build variables": [
  null,
  ""
 ],
 "Shared": [
  null,
  "Zdielaný"
 ],
 "Show": [
  null,
  ""
 ],
 "Show intermediate images": [
  null,
  ""
 ],
 "Size": [
  null,
  "Veľkosť"
 ],
 "Start": [
  null,
  "Spustiť"
 ],
 "Start podman": [
  null,
  "Spustiť podman"
 ],
 "State": [
  null,
  "Stav"
 ],
 "Stop": [
  null,
  "Zastaviť"
 ],
 "Stopped": [
  null,
  "Zastavený"
 ],
 "Support preserving established TCP connections": [
  null,
  ""
 ],
 "System": [
  null,
  "Systém"
 ],
 "System Podman service is also available": [
  null,
  "Systémový podman je tiež dostupný"
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "Tag"
 ],
 "Tags": [
  null,
  "Tagy"
 ],
 "Troubleshoot": [
  null,
  "Riešiť problém"
 ],
 "Type to filter…": [
  null,
  ""
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  "Aktívny od $0"
 ],
 "Used by": [
  null,
  "Využívaný s"
 ],
 "User": [
  null,
  ""
 ],
 "User Podman service is also available": [
  null,
  "Užívateľský podman je tiež dostupný"
 ],
 "Value": [
  null,
  "Hodnota"
 ],
 "Volumes": [
  null,
  "Zväzky"
 ],
 "With terminal": [
  null,
  "S terminálom"
 ],
 "configured": [
  null,
  ""
 ],
 "container": [
  null,
  "kontajner"
 ],
 "created": [
  null,
  "vytvorený"
 ],
 "exited": [
  null,
  "skončený"
 ],
 "image": [
  null,
  "obraz"
 ],
 "in": [
  null,
  ""
 ],
 "n/a": [
  null,
  "Nedostupné"
 ],
 "not available": [
  null,
  "nedostupné"
 ],
 "paused": [
  null,
  "pozastavený"
 ],
 "pod group": [
  null,
  ""
 ],
 "podman": [
  null,
  "podman"
 ],
 "removing": [
  null,
  ""
 ],
 "running": [
  null,
  ""
 ],
 "select all": [
  null,
  ""
 ],
 "stopped": [
  null,
  ""
 ],
 "system": [
  null,
  "systém"
 ]
}));

==> cockpit-podman-30-1-x86_64.pkg.tar.zst: usr/share/cockpit/podman/po.sk.js <==
cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;
return plural;
},
  "language": "sk",
  "x-generator": "Weblate 4.3.2"
 },
 "Add item": [
  null,
  "Pridať položku"
 ],
 "Add on build variable": [
  null,
  ""
 ],
 "All": [
  null,
  "Všetky"
 ],
 "All registries": [
  null,
  "Všetky registre"
 ],
 "An error occured": [
  null,
  "Vyskytla sa chyba"
 ],
 "Author": [
  null,
  "Autor"
 ],
 "Automatically start podman on boot": [
  null,
  "Spúšťať podman pri zavádzaní systému"
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU shares": [
  null,
  "CPU podiely"
 ],
 "Cancel": [
  null,
  "Zrušiť"
 ],
 "Checkpoint": [
  null,
  "Vytvoriť kontrolný bod"
 ],
 "Checkpoint container $0": [
  null,
  "Vytvoriť kontrolný bod pre kontajner $0"
 ],
 "Command": [
  null,
  "Príkaz"
 ],
 "Commit": [
  null,
  "Vytvoriť"
 ],
 "Commit image": [
  null,
  "Vytvoriť obraz"
 ],
 "Console": [
  null,
  "Konzola"
 ],
 "Container": [
  null,
  "Kontajner"
 ],
 "Container failed to be created": [
  null,
  "Kontajner sa nepodarilo vytvoriť"
 ],
 "Container failed to be started": [
  null,
  "Kontajner sa nepodarilo spustiť"
 ],
 "Container is currently running.": [
  null,
  "Kontajner momentálne beží."
 ],
 "Container is not running": [
  null,
  "Kontajner nebeží"
 ],
 "Container name": [
  null,
  "Názov kontajneru"
 ],
 "Container path": [
  null,
  "Cesta v kontajneri"
 ],
 "Container port": [
  null,
  "Port kontajneru"
 ],
 "Containers": [
  null,
  "Kontajnery"
 ],
 "Created": [
  null,
  "Vytvorený"
 ],
 "Delete": [
  null,
  "Odstrániť"
 ],
 "Delete $0": [
  null,
  "Odstrániť $0"
 ],
 "Delete image": [
  null,
  "Zmazať obraz"
 ],
 "Delete tagged images": [
  null,
  "Zmazať označené obrazy"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "Zmazaním kontajneru sa zmažú všetky dáta v ňom."
 ],
 "Deleting this pod will remove the following containers:": [
  null,
  "Zmazanie tohto podu zmaže nasledujúce kontajnery:"
 ],
 "Details": [
  null,
  "Podrobnosti"
 ],
 "Do not include root file-system changes when exporting": [
  null,
  "Do exportu nezahŕnať zmeny v koreňovom súborovovom systéme"
 ],
 "Download": [
  null,
  "Stiahnuť"
 ],
 "Entrypoint": [
  null,
  "Vstupný bod"
 ],
 "Environment": [
  null,
  "Prostredie"
 ],
 "Error": [
  null,
  "Chyba"
 ],
 "Error message": [
  null,
  "Chybová správa"
 ],
 "Error occured while connecting console": [
  null,
  ""
 ],
 "Exited": [
  null,
  "Skončený"
 ],
 "Failed to checkpoint container $0": [
  null,
  "Nepodarilo sa vytvoriť kontrolný bod pre kontajner $0"
 ],
 "Failed to commit container $0": [
  null,
  ""
 ],
 "Failed to download image $0:$1": [
  null,
  "Nepodarilo sa stiahnuť obraz $0:$1"
 ],
 "Failed to force remove container $0": [
  null,
  "Nepodarilo sa vynútiť zmazanie kontajneru $0"
 ],
 "Failed to force stop pod $0": [
  null,
  "Nepodarilo sa vynútiť zmazanie podu $0"
 ],
 "Failed to pause pod $0": [
  null,
  "Nepodarilo sa zastaviť pod $0"
 ],
 "Failed to remove container $0": [
  null,
  "Nepodarilo sa zmazať kontajner $0"
 ],
 "Failed to restart container $0": [
  null,
  "Nepodarilo sa reštartovať kontajner $0"
 ],
 "Failed to restart pod $0": [
  null,
  "Nepodarilo sa reštartovať pod $0"
 ],
 "Failed to restore container $0": [
  null,
  "Nepodarilo sa obnoviť kontajner $0"
 ],
 "Failed to resume pod $0": [
  null,
  "Nepodarilo sa znovuspustiť pod $0"
 ],
 "Failed to search for images: $0": [
  null,
  "Nepodarilo sa nájsť obrazy: $0"
 ],
 "Failed to search for new images": [
  null,
  "Nepodarilo sa nájsť nové obrazy"
 ],
 "Failed to start container $0": [
  null,
  "Nepodarilo sa spustiť kontajner $0"
 ],
 "Failed to start pod $0": [
  null,
  "Nepodarilo sa spustiť pod $0"
 ],
 "Failed to stop container $0": [
  null,
  "Nepodarilo sa zastaviť kontajner $0"
 ],
 "Failed to stop pod $0": [
  null,
  "Nepodarilo sa zastaviť pod $0"
 ],
 "Force delete": [
  null,
  "Vynútiť odstránenie"
 ],
 "Force restart": [
  null,
  "Vynútiť reštartovanie"
 ],
 "Force stop": [
  null,
  "Vynútiť zastavenie"
 ],
 "Format": [
  null,
  "Formát"
 ],
 "Gateway": [
  null,
  "Brána"
 ],
 "Get new image": [
  null,
  "Získať nové obrazy"
 ],
 "GiB": [
  null,
  "GiB"
 ],
 "Hide intermediate images": [
  null,
  "Skryť dočasné obrazy"
 ],
 "Host path": [
  null,
  "Cesta na hostiteľovi"
 ],
 "ID": [
  null,
  "ID"
 ],
 "IP (optional)": [
  null,
  ""
 ],
 "IP address": [
  null,
  "IP adresa"
 ],
 "IP prefix length": [
  null,
  "Dĺžka predpony IP adresy"
 ],
 "Ignore IP address if set statically": [
  null,
  "Ignorovať staticky nastavené IP adresy"
 ],
 "Ignore MAC address if set statically": [
  null,
  "Ignorovať staticky nastavené MAC adresy"
 ],
 "Image": [
  null,
  "Obraz"
 ],
 "Image name": [
  null,
  "Názov obrazu"
 ],
 "Images": [
  null,
  "Obrazy"
 ],
 "Keep all temporary checkpoint files": [
  null,
  ""
 ],
 "Key": [
  null,
  "Kľúč"
 ],
 "KiB": [
  null,
  "KiB"
 ],
 "Leave running after writing checkpoint to disk": [
  null,
  ""
 ],
 "Loading logs...": [
  null,
  "Načítanie záznamov udalostí..."
 ],
 "Loading...": [
  null,
  "Načítanie..."
 ],
 "Logs": [
  null,
  "Záznamy udalostí"
 ],
 "MAC address": [
  null,
  "MAC adresa"
 ],
 "Memory": [
  null,
  "Pamäť"
 ],
 "Memory limit": [
  null,
  "Pamäťový limit"
 ],
 "Message": [
  null,
  "Správa"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Mode": [
  null,
  ""
 ],
 "Multiple tags exist for this image. Select the tagged images to delete.": [
  null,
  ""
 ],
 "Name": [
  null,
  "Názov"
 ],
 "No SELinux label": [
  null,
  ""
 ],
 "No containers": [
  null,
  "Žiadne kontajnery"
 ],
 "No containers are using this image": [
  null,
  "Tento obraz nepoužívajú žiadne kontajnery"
 ],
 "No containers in this pod": [
  null,
  "V tomto pode nie sú žiadne kontajnery"
 ],
 "No containers that match the current filter": [
  null,
  ""
 ],
 "No images": [
  null,
  "Žiadne obrazy"
 ],
 "No images that match the current filter": [
  null,
  ""
 ],
 "No results for $0": [
  null,
  ""
 ],
 "No running containers": [
  null,
  "Žiadne spustené kontajnery"
 ],
 "Only running": [
  null,
  ""
 ],
 "Owner": [
  null,
  "Vlastník"
 ],
 "Pause": [
  null,
  "Pozastaviť"
 ],
 "Pause the container": [
  null,
  "Pozastaviť kontajner"
 ],
 "Paused": [
  null,
  "Pozastavený"
 ],
 "Please confirm deletion of $0": [
  null,
  "Potvrďte zmazanie $0"
 ],
 "Please confirm deletion of pod $0": [
  null,
  "Potvrďte zmazanie podu $0"
 ],
 "Please confirm force deletion of pod $0": [
  null,
  "Potvrďte vynútené zmazanie podu $0"
 ],
 "Please confirm forced deletion of $0": [
  null,
  ""
 ],
 "Please start typing to look for images.": [
  null,
  ""
 ],
 "Podman containers": [
  null,
  "Podman kontajnery"
 ],
 "Podman service is not active": [
  null,
  "Služba Podman nie je aktívna"
 ],
 "Ports": [
  null,
  "Porty"
 ],
 "Private": [
  null,
  ""
 ],
 "Protocol": [
  null,
  ""
 ],
 "Pulling": [
  null,
  "Sťahuje sa"
 ],
 "ReadOnly": [
  null,
  ""
 ],
 "ReadWrite": [
  null,
  ""
 ],
 "Remove item": [
  null,
  ""
 ],
 "Remove on build variable": [
  null,
  ""
 ],
 "Restart": [
  null,
  "Reštartovať"
 ],
 "Restore": [
  null,
  "Obnoviť"
 ],
 "Restore container $0": [
  null,
  "Obnovenie kontajneru $0"
 ],
 "Restore with established TCP connections": [
  null,
  ""
 ],
 "Resume": [
  null,
  ""
 ],
 "Run": [
  null,
  "Spustiť"
 ],
 "Run image": [
  null,
  "Spustiť obraz"
 ],
 "Running": [
  null,
  ""
 ],
 "SELinux label": [
  null,
  ""
 ],
 "Search by name or description": [
  null,
  "Hľadať podľa mena alebo popisu"
 ],
 "Search for": [
  null,
  ""
 ],
 "Search for an image": [
  null,
  "Hľadanie obrazu"
 ],
 "Set container on build variables": [
  null,
  ""
 ],
 "Shared": [
  null,
  "Zdielaný"
 ],
 "Show": [
  null,
  ""
 ],
 "Show intermediate images": [
  null,
  ""
 ],
 "Size": [
  null,
  "Veľkosť"
 ],
 "Start": [
  null,
  "Spustiť"
 ],
 "Start podman": [
  null,
  "Spustiť podman"
 ],
 "State": [
  null,
  "Stav"
 ],
 "Stop": [
  null,
  "Zastaviť"
 ],
 "Stopped": [
  null,
  "Zastavený"
 ],
 "Support preserving established TCP connections": [
  null,
  ""
 ],
 "System": [
  null,
  "Systém"
 ],
 "System Podman service is also available": [
  null,
  "Systémový podman je tiež dostupný"
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "Tag"
 ],
 "Tags": [
  null,
  "Tagy"
 ],
 "Troubleshoot": [
  null,
  "Riešiť problém"
 ],
 "Type to filter…": [
  null,
  ""
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  "Aktívny od $0"
 ],
 "Used by": [
  null,
  "Využívaný s"
 ],
 "User": [
  null,
  ""
 ],
 "User Podman service is also available": [
  null,
  "Užívateľský podman je tiež dostupný"
 ],
 "Value": [
  null,
  "Hodnota"
 ],
 "Volumes": [
  null,
  "Zväzky"
 ],
 "With terminal": [
  null,
  "S terminálom"
 ],
 "configured": [
  null,
  ""
 ],
 "container": [
  null,
  "kontajner"
 ],
 "created": [
  null,
  "vytvorený"
 ],
 "exited": [
  null,
  "skončený"
 ],
 "image": [
  null,
  "obraz"
 ],
 "in": [
  null,
  ""
 ],
 "n/a": [
  null,
  "Nedostupné"
 ],
 "not available": [
  null,
  "nedostupné"
 ],
 "paused": [
  null,
  "pozastavený"
 ],
 "pod group": [
  null,
  ""
 ],
 "podman": [
  null,
  "podman"
 ],
 "removing": [
  null,
  ""
 ],
 "running": [
  null,
  ""
 ],
 "select all": [
  null,
  ""
 ],
 "stopped": [
  null,
  ""
 ],
 "system": [
  null,
  "systém"
 ]
});
